@@ -1,4 +1,5 @@
 <?php $TRANSLATIONS = array(
+"No file provided for import" => "沒有提供匯入用的檔案",
 "Unsupported file type for import" => "不支援這種檔案類型的匯入",
 "Bookmarks" => "書籤",
 "Tags" => "標籤",
@@ -6,6 +7,7 @@
 "Edit bookmark" => "編輯書籤",
 "Are you sure you want to remove this tag from every entry?" => "您確定要從每個項目中移除這個標籤嗎？",
 "Warning" => "警告",
+"Import error" => "匯入錯誤",
 "Import completed successfully." => "匯入成功完成。",
 "Uploading..." => "上傳中...",
 "Bookm." => "書籤",
@@ -18,13 +20,12 @@
 "Delete" => "刪除",
 "Edit" => "編輯",
 "Cancel" => "取消",
-"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "將此拖曳至您的瀏覽器書籤並點擊, 當你想要將網頁快速地加入書籤:",
-"Read later" => "稍後閱讀",
+"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "把這個拖曳至瀏覽器的書籤列，下次您想要將某個頁面加至書籤時，點一下書籤列上面的這個項目即可。",
 "Address" => "網址",
 "Add" => "新增",
 "Related Tags" => "相關標籤",
 "Settings" => "設定",
-"You have no bookmarks" => "你沒有書籤",
+"You have no bookmarks" => "您還沒有任何書籤",
 "You can also try to import a bookmark file" => "您也可以匯入書籤檔",
 "Bookmarklet" => "Bookmarklet",
 "Export & Import" => "匯出與匯入",
