@@ -16,16 +16,13 @@
 "Deletion failed" => "Fejl ved sletning",
 "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
 "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
-"user" => "bruger",
 "group" => "gruppe",
-"Editable" => "Redigerbar",
-"Shareable" => "Kan deles",
-"Deletable" => "Kan slettes",
+"can edit" => "kan redigere",
 "ddd" => "ddd",
 "ddd M/d" => "ddd M/d",
 "dddd M/d" => "dddd M/d",
 "MMMM yyyy" => "MMMM yyyy",
-"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
+"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
 "dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
 "Sunday" => "Søndag",
 "Monday" => "Mandag",
@@ -98,9 +95,6 @@
 "You do not have the permissions to add events to this calendar." => "Du har ikke rettigheder til at tilføje begivenheder til denne kalender.",
 "You do not have the permissions to delete this event." => "Du har ikke rettigheder til at slette denne begivenhed.",
 "Busy" => "Optaget",
-"Public" => "Offentlig",
-"Private" => "Privat",
-"Confidential" => "Fortrolig",
 "Does not repeat" => "Gentages ikke",
 "Daily" => "Dagligt",
 "Weekly" => "Ugentligt",
@@ -124,47 +118,38 @@
 "by yearday(s)" => "efter dag(e) i året",
 "by weeknumber(s)" => "efter ugenummer/-numre",
 "by day and month" => "efter dag og måned",
+"Contact birthdays" => "Kontakt fødselsdage",
 "Date" => "Dato",
 "Cal." => "Kal.",
+"Day" => "Dag",
 "Week" => "Uge",
 "Month" => "Måned",
-"List" => "Liste",
 "Today" => "I dag",
 "Settings" => "Indstillinger",
-"Your calendars" => "Dine kalendere",
-"CalDav Link" => "CalDav-link",
 "Share Calendar" => "Del kalender",
+"CalDav Link" => "CalDav-link",
 "Download" => "Hent",
 "Edit" => "Rediger",
 "Delete" => "Slet",
 "New calendar" => "Ny kalender",
 "Edit calendar" => "Rediger kalender",
 "Displayname" => "Vist navn",
-"Active" => "Aktiv",
 "Calendar color" => "Kalenderfarve",
 "Save" => "Gem",
 "Submit" => "Send",
 "Cancel" => "Annuller",
-"Edit an event" => "Rediger en begivenhed",
-"Export" => "Eksporter",
 "Eventinfo" => "Begivenhedsinfo",
 "Repeating" => "Gentagende",
 "Alarm" => "Alarm",
 "Attendees" => "Deltagere",
 "Share" => "Del",
 "Title of the Event" => "Titel på begivenheden",
-"Category" => "Kategori",
-"Separate categories with commas" => "Adskil kategorier med kommaer",
-"Edit categories" => "Rediger kategorier",
-"Access Class" => "Adgangsklasse",
+"from" => "fra",
 "All Day Event" => "Heldagsarrangement",
-"From" => "Fra",
-"To" => "Til",
 "Advanced options" => "Avancerede indstillinger",
 "Location" => "Sted",
-"Location of the Event" => "Placering af begivenheden",
+"Edit categories" => "Rediger kategorier",
 "Description" => "Beskrivelse",
-"Description of the Event" => "Beskrivelse af begivenheden",
 "Repeat" => "Gentag",
 "Advanced" => "Avanceret",
 "Select weekdays" => "Vælg ugedage",
@@ -187,16 +172,18 @@
 "Import" => "Importer",
 "Close Dialog" => "Luk dialog",
 "Create a new event" => "Opret en ny begivenhed",
-"Share with:" => "Del med:",
-"Shared with" => "Delt med",
 "Unshare" => "Fjern deling",
-"Nobody" => "Ingen",
+"Send Email" => "Send Email",
 "Shared via calendar" => "Delt via kalender",
-"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "NB! Handlinger på begivenheder delt via kalenderen vil berøre hele kalenderdelingen.",
 "View an event" => "Vis en begivenhed",
+"Category" => "Kategori",
 "No categories selected" => "Ingen categorier valgt",
 "of" => "fra",
+"Access Class" => "Adgangsklasse",
+"From" => "Fra",
 "at" => "kl.",
+"To" => "Til",
+"Your calendars" => "Dine kalendere",
 "General" => "Generel",
 "Timezone" => "Tidszone",
 "Update timezone automatically" => "Opdater tidszone automatisk",
