@@ -1,6 +1,8 @@
 <?php $TRANSLATIONS = array(
 "Save" => "সংরক্ষণ কর",
+"Search" => "অনুসন্ধান",
 "Close" => "বন্ধ",
+"Next" => "পরবর্তী",
 "Saving..." => "সংরক্ষণ করা হচ্ছে....",
 "An error occurred!" => "সমস্যা দেখা দিয়েছে !",
 "There were unsaved changes, click here to go back" => "পরিবর্তনসমূহ সংরক্ষণ করা হয় নি, ফিরে যেতে এখানে ক্লিক করুন"
