@@ -19,7 +19,7 @@ class Downloader {
 	protected static $package = false;
 
 	public static function getPackage($url, $version) {
-		self::$package = \OC_Helper::tmpFile();
+		self::$package = \OCP\Files::tmpFile();
 		if (!self::$package){
 			throw new \Exception('Unable to create a temporary file');
 		}
@@ -59,9 +59,9 @@ class Downloader {
 		//  to have '3rdparty', 'apps' and 'core' subdirectories
 		$sources = Helper::getSources($version);
 		$baseDir = $extractDir. '/' . self::PACKAGE_ROOT;
-		@rename($baseDir . '/' . Helper::THIRDPARTY_DIRNAME, $sources[Helper::THIRDPARTY_DIRNAME]);
-		@rename($baseDir . '/' . Helper::APP_DIRNAME, $sources[Helper::APP_DIRNAME]);
-		@rename($baseDir, $sources[Helper::CORE_DIRNAME]);
+		rename($baseDir . '/' . Helper::THIRDPARTY_DIRNAME, $sources[Helper::THIRDPARTY_DIRNAME]);
+		rename($baseDir . '/' . Helper::APP_DIRNAME, $sources[Helper::APP_DIRNAME]);
+		rename($baseDir, $sources[Helper::CORE_DIRNAME]);
 	}
 	
 	/* To be replaced with OC_Util::getUrlContent for 5.x */
@@ -94,6 +94,10 @@ class Downloader {
 		Helper::removeIfExists(self::getPackageDir($version));
 	}
 	
+	public static function isClean($version){
+		return !@file_exists(self::getPackageDir($version));
+	}
+	
 	public static function getPackageDir($version) {
 		return App::getBackupBase() . $version;
 	}
